sd <-
function(x) sqrt(var(x))

